# YarpTp Python Module

YarpTp es un módulo para Python construido para un fácil control de la plataforma robótica YarpTp. Con él, cualquiera podrá construir scripts que ejecuten movimientos del robot de forma fácil.

## Instalación

### Requerimientos

El módulo está diseñado para usarse sobre la plataforma robótica YarpTp cuyo controlador es una Raspberry Pi. Por lo tanto, el módulo sólo tendrá efecto si se usa en la arquitectura de una Raspberry Pi.

La librería requerida por el módulo es:

 * RPi.GPIO (versión mínima 0.6.3) módulo de python para el control de los pines GPIO.

### Instalación

El paquete puede descargarse desde PyPi o usando el gestor de paquetes pip a través del comando:

  ``$ pip install YarpTp``

## Documentación

Para mayor información, puede visitar la documentación alojada [aquí](https://documentacion-del-modulo-yarptp.readthedocs.io).
